==> jc-1.4.0.tar.gz: soot/jimple/internal/JSpecialInvokeExpr.h <==
// public class soot.jimple.internal.JSpecialInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr
// @dep_class a4fd17ea76ff6f29 soot_jimple_internal_JSpecialInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractSpecialInvokeExpr

#include "soot/jimple/internal/AbstractSpecialInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JSpecialInvokeExpr_H_
#define _JC_soot_jimple_internal_JSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs	_jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$refs	_jc_soot_jimple_internal_JSpecialInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs	_jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object	_jc_soot_jimple_internal_JSpecialInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods	_jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtable	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtype	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JSpecialInvokeExpr$method$_init$5ea199535ea679d7(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JSpecialInvokeExpr$method$_init$892bfbf9f91a9e78(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods	soot_jimple_internal_JSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$refs {
    _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs	soot_jimple_internal_JSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_JSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object {
	_jc_soot_jimple_internal_JSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JSpecialInvokeExpr$vtype _jc_soot_jimple_internal_JSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JSpecialInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JSpecialInvokeExpr.h <==
// public class soot.jimple.internal.JSpecialInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr
// @dep_class a4fd17ea76ff6f29 soot_jimple_internal_JSpecialInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractSpecialInvokeExpr

#include "soot/jimple/internal/AbstractSpecialInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JSpecialInvokeExpr_H_
#define _JC_soot_jimple_internal_JSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs	_jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$refs	_jc_soot_jimple_internal_JSpecialInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs	_jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object	_jc_soot_jimple_internal_JSpecialInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods	_jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtable	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtype	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JSpecialInvokeExpr$method$_init$5ea199535ea679d7(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JSpecialInvokeExpr$method$_init$892bfbf9f91a9e78(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$vmethods	soot_jimple_internal_JSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$refs {
    _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_refs	soot_jimple_internal_JSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_JSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_JSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JSpecialInvokeExpr$object {
	_jc_soot_jimple_internal_JSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JSpecialInvokeExpr$vtype _jc_soot_jimple_internal_JSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JSpecialInvokeExpr_H_ */
